@@ -41,7 +41,16 @@ elif hasattr(settings, "POLARIS_ENV_PATH"):
             f"Could not find env file at {settings.POLARIS_ENV_PATH}"
         )
 
-accepted_seps = ["sep-1", "sep-6", "sep-6", "sep-10", "sep-12", "sep-24", "sep-31"]
+accepted_seps = [
+    "sep-1",
+    "sep-6",
+    "sep-6",
+    "sep-10",
+    "sep-12",
+    "sep-24",
+    "sep-31",
+    "sep-38",
+]
 ACTIVE_SEPS = env_or_settings("ACTIVE_SEPS", list=True)
 for i, sep in enumerate(ACTIVE_SEPS):
     if sep.lower() not in accepted_seps:
@@ -130,6 +139,7 @@ ADDITIVE_FEES_ENABLED = (
 OPERATION_DEPOSIT = "deposit"
 OPERATION_WITHDRAWAL = "withdraw"
 ACCOUNT_STARTING_BALANCE = str(2.01)
+DATETIME_FORMAT = "%Y-%m-%dT%H:%M:%S.%fZ"
 
 INTERACTIVE_JWT_EXPIRATION = (
     env_or_settings("INTERACTIVE_JWT_EXPIRATION", int=True, required=False) or 30
